# Copyright 2009-2014 Justin Riley
#
# This file is part of TethysCluster.
#
# TethysCluster is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# TethysCluster is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with TethysCluster. If not, see <http://www.gnu.org/licenses/>.

qhost_xml = """<?xml version='1.0'?>
<qhost xmlns:xsd="http://gridengine.sunsource.net/source/browse/*checkout*/\
gridengine/source/dist/util/resources/schemas/qhost/qhost.xsd?revision=1.2">
 <host name='global'>
   <hostvalue name='arch_string'>-</hostvalue>
   <hostvalue name='num_proc'>-</hostvalue>
   <hostvalue name='load_avg'>-</hostvalue>
   <hostvalue name='mem_total'>-</hostvalue>
   <hostvalue name='mem_used'>-</hostvalue>
   <hostvalue name='swap_total'>-</hostvalue>
   <hostvalue name='swap_used'>-</hostvalue>
 </host>
 <host name='ip-10-196-142-180.ec2.internal'>
   <hostvalue name='arch_string'>lx24-x86</hostvalue>
   <hostvalue name='num_proc'>1</hostvalue>
   <hostvalue name='load_avg'>0.03</hostvalue>
   <hostvalue name='mem_total'>1.7G</hostvalue>
   <hostvalue name='mem_used'>75.4M</hostvalue>
   <hostvalue name='swap_total'>896.0M</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='ip-10-196-214-162.ec2.internal'>
   <hostvalue name='arch_string'>lx24-x86</hostvalue>
   <hostvalue name='num_proc'>1</hostvalue>
   <hostvalue name='load_avg'>0.21</hostvalue>
   <hostvalue name='mem_total'>1.7G</hostvalue>
   <hostvalue name='mem_used'>88.9M</hostvalue>
   <hostvalue name='swap_total'>896.0M</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='ip-10-196-215-50.ec2.internal'>
   <hostvalue name='arch_string'>lx24-x86</hostvalue>
   <hostvalue name='num_proc'>1</hostvalue>
   <hostvalue name='load_avg'>0.06</hostvalue>
   <hostvalue name='mem_total'>1.7G</hostvalue>
   <hostvalue name='mem_used'>75.9M</hostvalue>
   <hostvalue name='swap_total'>896.0M</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
</qhost>"""

qstat_xml = """<?xml version='1.0'?>
<job_info  xmlns:xsd="http://gridengine.sunsource.net/source/browse/*checkout*\
/gridengine/source/dist/util/resources/schemas/qstat/qstat.xsd?revision=1.11">
  <queue_info>
    <Queue-List>
      <name>all.q@ip-10-196-142-180.ec2.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
      <job_list state="running">
        <JB_job_number>1</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sleep</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-06-18T23:39:24</JAT_start_time>
        <queue_name>all.q@ip-10-196-142-180.ec2.internal</queue_name>
        <slots>1</slots>
      </job_list>
    </Queue-List>
    <Queue-List>
      <name>all.q@ip-10-196-215-50.ec2.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
      <job_list state="running">
        <JB_job_number>2</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sleep</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-06-18T23:39:24</JAT_start_time>
        <queue_name>all.q@ip-10-196-215-50.ec2.internal</queue_name>
        <slots>1</slots>
      </job_list>
    </Queue-List>
    <Queue-List>
      <name>all.q@ip-10-196-214-162.ec2.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
      <job_list state="running">
        <JB_job_number>3</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sleep</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-06-18T23:39:24</JAT_start_time>
        <queue_name>all.q@ip-10-196-214-162.ec2.internal</queue_name>
        <slots>1</slots>
      </job_list>
    </Queue-List>
  </queue_info>
  <job_info>
    <job_list state="pending">
      <JB_job_number>4</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:14</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>5</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:14</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>6</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:14</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>7</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:15</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>8</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:15</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>9</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:16</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>10</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:16</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>11</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:17</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>12</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>13</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>14</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:36</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>15</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:36</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>16</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:37</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>17</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:37</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>18</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:38</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>19</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:38</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>20</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:38</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>21</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:39</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>22</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:39</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>23</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sleep</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-06-18T23:39:40</JB_submission_time>
      <queue_name></queue_name>
      <slots>1</slots>
    </job_list>
  </job_info>
</job_info>"""

loaded_qhost_xml = """<?xml version='2.0'?>
<qhost xmlns:xsd="http://gridengine.sunsource.net/source/browse/*checkout*/\
gridengine/source/dist/util/resources/schemas/qhost/qhost.xsd?revision=1.2">
 <host name='global'>
   <hostvalue name='arch_string'>-</hostvalue>
   <hostvalue name='num_proc'>-</hostvalue>
   <hostvalue name='load_avg'>-</hostvalue>
   <hostvalue name='mem_total'>-</hostvalue>
   <hostvalue name='mem_used'>-</hostvalue>
   <hostvalue name='swap_total'>-</hostvalue>
   <hostvalue name='swap_used'>-</hostvalue>
 </host>
 <host name='domU-12-31-39-0B-C4-61.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.32</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>997.4M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0B-C4-C1.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>9.65</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>1.0G</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0B-C6-51.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.25</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>996.6M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FC-31.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.21</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>997.2M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FC-71.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.10</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>997.0M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FC-D1.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.31</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>996.7M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FD-01.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.08</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>997.3M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FD-81.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.12</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>995.7M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FE-51.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.06</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>996.8M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
 <host name='domU-12-31-39-0E-FE-71.compute-1.internal'>
   <hostvalue name='arch_string'>lx24-amd64</hostvalue>
   <hostvalue name='num_proc'>8</hostvalue>
   <hostvalue name='load_avg'>8.17</hostvalue>
   <hostvalue name='mem_total'>7.0G</hostvalue>
   <hostvalue name='mem_used'>996.1M</hostvalue>
   <hostvalue name='swap_total'>0.0</hostvalue>
   <hostvalue name='swap_used'>0.0</hostvalue>
 </host>
</qhost>"""

qacct_txt = """==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    2
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:33 2010
start_time   Thu Jul 15 18:18:41 2010
end_time     Thu Jul 15 18:19:41 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    771
ru_majflt    0
ru_nswap     0
ru_inblock   16
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     4
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A5-A1.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    1
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:31 2010
start_time   Thu Jul 15 18:18:41 2010
end_time     Thu Jul 15 18:19:41 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    792
ru_majflt    0
ru_nswap     0
ru_inblock   16
ru_oublock   160
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     86
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    4
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:35 2010
start_time   Thu Jul 15 18:19:56 2010
end_time     Thu Jul 15 18:20:56 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      0.000
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A5-A1.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    3
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:34 2010
start_time   Thu Jul 15 18:19:56 2010
end_time     Thu Jul 15 18:20:56 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.010
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    790
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   160
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     84
ru_nivcsw    0
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    6
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:38 2010
start_time   Thu Jul 15 18:21:11 2010
end_time     Thu Jul 15 18:22:11 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A5-A1.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    5
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:18:36 2010
start_time   Thu Jul 15 18:21:11 2010
end_time     Thu Jul 15 18:22:11 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    792
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   160
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     84
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    7
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:13 2010
start_time   Thu Jul 15 18:34:26 2010
end_time     Thu Jul 15 18:35:26 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    8
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:14 2010
start_time   Thu Jul 15 18:35:41 2010
end_time     Thu Jul 15 18:36:41 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.010
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    9
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:14 2010
start_time   Thu Jul 15 18:36:56 2010
end_time     Thu Jul 15 18:37:56 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    775
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    10
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:15 2010
start_time   Thu Jul 15 18:38:11 2010
end_time     Thu Jul 15 18:39:11 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    774
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    11
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:15 2010
start_time   Thu Jul 15 18:39:26 2010
end_time     Thu Jul 15 18:40:26 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    775
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    12
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:16 2010
start_time   Thu Jul 15 18:40:41 2010
end_time     Thu Jul 15 18:41:41 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    775
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    13
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:16 2010
start_time   Thu Jul 15 18:41:56 2010
end_time     Thu Jul 15 18:42:56 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    774
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    14
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:17 2010
start_time   Thu Jul 15 18:43:11 2010
end_time     Thu Jul 15 18:44:11 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    774
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.000
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    15
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:17 2010
start_time   Thu Jul 15 18:44:26 2010
end_time     Thu Jul 15 18:45:26 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.010
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    16
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:18 2010
start_time   Thu Jul 15 18:45:41 2010
end_time     Thu Jul 15 18:46:41 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.010
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    772
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    17
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:34:20 2010
start_time   Thu Jul 15 18:46:56 2010
end_time     Thu Jul 15 18:47:56 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 60
ru_utime     0.000
ru_stime     0.010
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    774
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    0
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
==============================================================
qname        all.q
hostname     domU-12-31-38-00-A6-41.compute-1.internal
group        root
owner        root
project      NONE
department   defaultdepartment
jobname      sleep
jobnumber    18
taskid       undefined
account      sge
priority     0
qsub_time    Thu Jul 15 18:50:58 2010
start_time   Thu Jul 15 18:51:11 2010
end_time     Thu Jul 15 19:01:11 2010
granted_pe   NONE
slots        1
failed       0
exit_status  0
ru_wallclock 600
ru_utime     0.010
ru_stime     0.000
ru_maxrss    0
ru_ixrss     0
ru_ismrss    0
ru_idrss     0
ru_isrss     0
ru_minflt    773
ru_majflt    0
ru_nswap     0
ru_inblock   0
ru_oublock   8
ru_msgsnd    0
ru_msgrcv    0
ru_nsignals  0
ru_nvcsw     2
ru_nivcsw    1
cpu          0.010
mem          0.000
io           0.000
iow          0.000
maxvmem      2.902M
arid         undefined
Total System Usage
    WALLCLOCK         UTIME         STIME           CPU             \
MEMORY                 IO                IOW
====================================================================\
============================================
         1620         0.060         0.050         0.110              \
0.000              0.000              0.000
"""

loaded_qstat_xml = """<?xml version='1.0'?>
<job_info  xmlns:xsd="http://gridengine.sunsource.net/source/browse/*checkout\
*/gridengine/source/dist/util/resources/schemas/qstat/qstat.xsd?revision=1.11">
  <queue_info>
    <Queue-List>
      <name>all.q@domU-12-31-39-0B-C4-C1.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
      <job_list state="running">
        <JB_job_number>385</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sm-haar-str-kconico-r4-dc10</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-07-08T04:40:46</JAT_start_time>
        <queue_name>\
all.q@domU-12-31-39-0B-C4-C1.compute-1.internal</queue_name>
        <slots>20</slots>
      </job_list>
      <job_list state="running">
        <JB_job_number>386</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sm-haar-str-kconico-r4-dc7</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-07-08T04:40:47</JAT_start_time>
        <queue_name>\
all.q@domU-12-31-39-0B-C4-C1.compute-1.internal</queue_name>
        <slots>20</slots>
      </job_list>
      <job_list state="running">
        <JB_job_number>387</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sm-haar-str-kconico-r4-dc8</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-07-08T04:40:47</JAT_start_time>
        <queue_name>\
all.q@domU-12-31-39-0B-C4-C1.compute-1.internal</queue_name>
        <slots>20</slots>
      </job_list>
      <job_list state="running">
        <JB_job_number>388</JB_job_number>
        <JAT_prio>0.55500</JAT_prio>
        <JB_name>sm-haar-str-kconico-r4-dc9</JB_name>
        <JB_owner>root</JB_owner>
        <state>r</state>
        <JAT_start_time>2010-07-08T04:40:47</JAT_start_time>
        <queue_name>\
all.q@domU-12-31-39-0B-C4-C1.compute-1.internal</queue_name>
        <slots>20</slots>
      </job_list>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0B-C4-61.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0B-C6-51.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FC-31.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FC-71.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FC-D1.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FD-01.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FD-81.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FE-51.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
    <Queue-List>
      <name>all.q@domU-12-31-39-0E-FE-71.compute-1.internal</name>
      <qtype>BIP</qtype>
      <slots_used>0</slots_used>
      <slots_resv>0</slots_resv>
      <slots_total>8</slots_total>
      <load_avg>0.01000</load_avg>
      <arch>linux-x64</arch>
    </Queue-List>
  </queue_info>
  <job_info>
    <job_list state="pending">
      <JB_job_number>389</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>390</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>391</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>392</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>393</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>394</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>395</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>396</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>397</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>398</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>399</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>400</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconico-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>401</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>402</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>403</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>404</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>405</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>406</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>407</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>408</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>409</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>410</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>411</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>412</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>413</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>414</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>415</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>416</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kconic-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>417</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>418</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>419</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>420</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>421</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>422</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>423</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>424</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>425</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>426</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:32</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>427</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>428</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>429</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>430</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>431</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>432</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcylo-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>433</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>434</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>435</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>436</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>437</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>438</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>439</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>440</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>441</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>442</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>443</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>444</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>445</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>446</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>447</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>448</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kcyl-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>449</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>450</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>451</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>452</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>453</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>454</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>455</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>456</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>457</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>458</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>459</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>460</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>461</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>462</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>463</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>464</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquado-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>465</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>466</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>467</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>468</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>469</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>470</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>471</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>472</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>473</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>474</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>475</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>476</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>477</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>478</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>479</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>480</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-haar-str-kquad-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:33</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>481</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>482</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>483</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>484</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>485</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>486</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>487</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>488</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>489</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>490</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>491</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>492</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>493</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>494</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>495</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>496</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconico-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>497</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>498</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>499</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>500</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>501</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>502</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>503</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>504</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>505</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>506</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>507</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>508</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>509</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>510</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>511</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>512</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kconic-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>513</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>514</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>515</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>516</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>517</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>518</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>519</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>520</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>521</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>522</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>523</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>524</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>525</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>526</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>527</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>528</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcylo-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>529</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>530</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>531</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>532</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>533</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:34</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>534</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>535</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>536</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>537</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>538</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>539</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>540</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>541</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>542</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>543</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>544</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kcyl-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>545</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>546</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>547</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>548</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>549</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>550</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>551</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>552</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>553</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>554</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>555</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>556</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>557</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>558</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>559</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>560</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquado-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>561</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r4-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>562</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r4-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>563</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r4-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>564</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r4-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>565</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r5-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>566</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r5-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>567</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r5-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>568</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r5-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>569</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r6-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>570</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r6-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>571</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r6-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>572</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r6-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>573</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r7-dc10</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>574</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r7-dc7</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>575</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r7-dc8</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
    <job_list state="pending">
      <JB_job_number>576</JB_job_number>
      <JAT_prio>0.55500</JAT_prio>
      <JB_name>sm-main-kquad-r7-dc9</JB_name>
      <JB_owner>root</JB_owner>
      <state>qw</state>
      <JB_submission_time>2010-07-08T04:40:35</JB_submission_time>
      <queue_name></queue_name>
      <slots>20</slots>
    </job_list>
  </job_info>
</job_info>"""



# Copyright 2009-2014 Justin Riley
#
# This file is part of TethysCluster.
#
# TethysCluster is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# TethysCluster is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with TethysCluster. If not, see <http://www.gnu.org/licenses/>.

"""
TethysCluster Exception Classes
"""

import os

from tethyscluster import static
from tethyscluster.logger import log
from tethyscluster.templates import config, user_msgs


class BaseException(Exception):
    def __init__(self, *args):
        self.args = args
        self.msg = args[0]

    def __str__(self):
        return self.msg

    def explain(self):
        return "%s: %s" % (self.__class__.__name__, self.msg)


class CommandNotFound(BaseException):
    """Raised when command is not found on the system's PATH """
    def __init__(self, cmd):
        self.msg = "command not found: '%s'" % cmd


class RemoteCommandNotFound(CommandNotFound):
    """Raised when command is not found on a *remote* system's PATH """
    def __init__(self, cmd):
        self.msg = "command not found on remote system: '%s'" % cmd


class SSHError(BaseException):
    """Base class for all SSH related errors"""


class SSHConnectionError(SSHError):
    """Raised when ssh fails to to connect to a host (socket error)"""
    def __init__(self, host, port):
        self.msg = "failed to connect to host %s on port %s" % (host, port)


class SSHAuthException(SSHError):
    """Raised when an ssh connection fails to authenticate"""
    def __init__(self, user, host):
        self.msg = "failed to authenticate to host %s as user %s" % (host,
                                                                     user)


class SSHNoCredentialsError(SSHError):
    def __init__(self):
        self.msg = "No password or key specified"


class RemoteCommandFailed(SSHError):
    def __init__(self, msg, command, exit_status, output):
        self.msg = msg
        self.command = command
        self.exit_status = exit_status
        self.output = output


class SSHAccessDeniedViaAuthKeys(BaseException):
    """
    Raised when SSH access for a given user has been restricted via
    authorized_keys (common approach on UEC AMIs to allow root SSH access to be
    'toggled' via cloud-init)
    """
    def __init__(self, user):
        self.msg = user_msgs.authkeys_access_denied % dict(user=user)


class SCPException(BaseException):
    """SCP exception class"""
    pass


class AWSError(BaseException):
    """Base exception for all AWS related errors"""


class RegionDoesNotExist(AWSError):
    def __init__(self, region_name):
        self.msg = "region %s does not exist" % region_name


class AMIDoesNotExist(AWSError):
    def __init__(self, image_id):
        self.msg = "AMI %s does not exist" % image_id


class InstanceDoesNotExist(AWSError):
    def __init__(self, instance_id, label='instance'):
        self.msg = "%s '%s' does not exist" % (label, instance_id)


class InstanceNotRunning(AWSError):
    def __init__(self, instance_id, state, label='instance'):
        self.msg = "%s %s is not running (%s)" % (label, instance_id, state)


class SubnetDoesNotExist(AWSError):
    def __init__(self, subnet_id):
        self.msg = "subnet does not exist: %s" % subnet_id


class SecurityGroupDoesNotExist(AWSError):
    def __init__(self, sg_name):
        self.msg = "security group %s does not exist" % sg_name


class PlacementGroupDoesNotExist(AWSError):
    def __init__(self, pg_name):
        self.msg = "placement group %s does not exist" % pg_name


class KeyPairAlreadyExists(AWSError):
    def __init__(self, keyname):
        self.msg = "keypair %s already exists" % keyname


class KeyPairDoesNotExist(AWSError):
    def __init__(self, keyname):
        self.msg = "keypair %s does not exist" % keyname


class ZoneDoesNotExist(AWSError):
    def __init__(self, zone, region):
        self.msg = "zone %s does not exist in region %s" % (zone, region)


class VolumeDoesNotExist(AWSError):
    def __init__(self, vol_id):
        self.msg = "volume %s does not exist" % vol_id


class SnapshotDoesNotExist(AWSError):
    def __init__(self, snap_id):
        self.msg = "snapshot %s does not exist" % snap_id


class BucketAlreadyExists(AWSError):
    def __init__(self, bucket_name):
        self.msg = "bucket with name '%s' already exists on S3\n" % bucket_name
        self.msg += "(NOTE: S3's bucket namespace is shared by all AWS users)"


class BucketDoesNotExist(AWSError):
    def __init__(self, bucket_name):
        self.msg = "bucket '%s' does not exist" % bucket_name


class InvalidOperation(AWSError):
    pass


class InvalidBucketName(AWSError):
    def __init__(self, bucket_name):
        self.msg = "bucket name %s is not valid" % bucket_name


class InvalidImageName(AWSError):
    def __init__(self, image_name):
        self.msg = "image name %s is not valid" % image_name


class AWSUserIdRequired(AWSError):
    def __init__(self):
        self.msg = "No Amazon user id specified in config (AWS_USER_ID)"


class EC2CertRequired(AWSError):
    def __init__(self):
        self.msg = "No certificate file (pem) specified in config (EC2_CERT)"


class EC2PrivateKeyRequired(AWSError):
    def __init__(self):
        self.msg = "No private certificate file (pem) file specified in "
        self.msg += "config (EC2_PRIVATE_KEY)"


class EC2CertDoesNotExist(AWSError):
    def __init__(self, key):
        self.msg = "EC2 certificate file %s does not exist" % key


class EC2PrivateKeyDoesNotExist(AWSError):
    def __init__(self, key):
        self.msg = "EC2 private key file %s does not exist" % key


class SpotHistoryError(AWSError):
    def __init__(self, start, end):
        self.msg = "no spot price history for the dates specified: "
        self.msg += "%s - %s" % (start, end)


class PropagationException(AWSError):
    pass


class InvalidIsoDate(BaseException):
    def __init__(self, date):
        self.msg = "Invalid date specified: %s" % date


class InvalidHostname(BaseException):
    pass


class ConfigError(BaseException):
    """Base class for all config related errors"""


class ConfigSectionMissing(ConfigError):
    pass


class ConfigHasNoSections(ConfigError):
    def __init__(self, cfg_file):
        self.msg = "No valid sections defined in config file %s" % cfg_file


class PluginNotFound(ConfigError):
    def __init__(self, plugin):
        self.msg = 'Plugin "%s" not found in config' % plugin


class NoDefaultTemplateFound(ConfigError):
    def __init__(self, options=None):
        msg = "No default cluster template specified.\n\n"
        msg += "To set the default cluster template, set DEFAULT_TEMPLATE "
        msg += "in the [global] section of the config to the name of one of "
        msg += "your cluster templates"
        optlist = ', '.join(options)
        if options:
            msg += '\n\nCurrent Templates:\n\n' + optlist
        self.msg = msg
        self.options = options
        self.options_list = optlist


class ConfigNotFound(ConfigError):
    def __init__(self, *args):
        self.msg = args[0]
        self.cfg = args[1]
        self.template = config.copy_paste_template

    def create_config(self):
        cfg_parent_dir = os.path.dirname(self.cfg)
        if not os.path.exists(cfg_parent_dir):
            os.makedirs(cfg_parent_dir)
        cfg_file = open(self.cfg, 'w')
        cfg_file.write(config.config_template)
        cfg_file.close()
        os.chmod(self.cfg, 0600)
        log.info("Config template written to %s" % self.cfg)
        log.info("Please customize the config template")

    def display_options(self):
        print 'Options:'
        print '--------'
        print '[1] Show the TethysCluster config template'
        print '[2] Write config template to %s' % self.cfg
        print '[q] Quit'
        resp = raw_input('\nPlease enter your selection: ')
        if resp == '1':
            print self.template
        elif resp == '2':
            print
            self.create_config()


class KeyNotFound(ConfigError):
    def __init__(self, keyname):
        self.msg = "key %s not found in config" % keyname


class InvalidDevice(BaseException):
    def __init__(self, device):
        self.msg = "invalid device specified: %s" % device


class InvalidPartition(BaseException):
    def __init__(self, part):
        self.msg = "invalid partition specified: %s" % part


class PluginError(BaseException):
    """Base class for plugin errors"""


class PluginLoadError(PluginError):
    """Raised when an error is encountered while loading a plugin"""


class PluginSyntaxError(PluginError):
    """Raised when plugin contains syntax errors"""


class ValidationError(BaseException):
    """Base class for validation related errors"""


class ClusterReceiptError(BaseException):
    """Raised when creating/loading a cluster receipt fails"""


class ClusterValidationError(ValidationError):
    """Cluster validation related errors"""


class NoClusterNodesFound(ValidationError):
    """Raised if no cluster nodes are found"""
    def __init__(self, terminated=None):
        self.msg = "No active cluster nodes found!"
        if not terminated:
            return
        self.msg += "\n\nBelow is a list of terminated instances:\n"
        for tnode in terminated:
            id = tnode.id
            reason = 'N/A'
            if tnode.state_reason:
                reason = tnode.state_reason['message']
            state = tnode.state
            self.msg += "\n%s (%s) %s" % (id, state, reason)


class NoClusterSpotRequests(ValidationError):
    """Raised if no spot requests belonging to a cluster are found"""
    def __init__(self):
        self.msg = "No cluster spot requests found!"


class MasterDoesNotExist(ClusterValidationError):
    """Raised when no master node is available"""
    def __init__(self):
        self.msg = "No master node found!"


class IncompatibleSettings(ClusterValidationError):
    """Raised when two or more settings conflict with each other"""


class InvalidProtocol(ClusterValidationError):
    """Raised when user specifies an invalid IP protocol for permission"""
    def __init__(self, protocol):
        self.msg = "protocol %s is not a valid ip protocol. options: %s"
        self.msg %= (protocol, ', '.join(static.PROTOCOLS))


class InvalidPortRange(ClusterValidationError):
    """Raised when user specifies an invalid port range for permission"""
    def __init__(self, from_port, to_port, reason=None):
        self.msg = ''
        if reason:
            self.msg += "%s\n" % reason
        self.msg += "port range is invalid: from %s to %s" % (from_port,
                                                              to_port)


class InvalidCIDRSpecified(ClusterValidationError):
    """Raised when user specifies an invalid CIDR ip for permission"""
    def __init__(self, cidr):
        self.msg = "cidr_ip is invalid: %s" % cidr


class InvalidZone(ClusterValidationError):
    """
    Raised when a zone has been specified that does not match the common
    zone of the volumes being attached
    """
    def __init__(self, zone, common_vol_zone):
        cvz = common_vol_zone
        self.msg = ("availability_zone setting '%s' does not "
                    "match the common volume zone '%s'") % (zone, cvz)


class VolumesZoneError(ClusterValidationError):
    def __init__(self, volumes):
        vlist = ', '.join(volumes)
        self.msg = 'Volumes %s are not in the same availability zone' % vlist


class ClusterTemplateDoesNotExist(BaseException):
    """
    Exception raised when user requests a cluster template that does not exist
    """
    def __init__(self, cluster_name):
        self.msg = "cluster template %s does not exist" % cluster_name


class ClusterNotRunning(BaseException):
    """
    Exception raised when user requests a running cluster that does not exist
    """
    def __init__(self, cluster_name):
        self.msg = "cluster %s is not running" % cluster_name


class ClusterDoesNotExist(BaseException):
    """
    Exception raised when user requests a running cluster that does not exist
    """
    def __init__(self, cluster_name):
        self.msg = "cluster '%s' does not exist" % cluster_name


class ClusterExists(BaseException):
    def __init__(self, cluster_name, is_ebs=False, stopped_ebs=False):
        ctx = dict(cluster_name=cluster_name)
        if stopped_ebs:
            self.msg = user_msgs.stopped_ebs_cluster % ctx
        elif is_ebs:
            self.msg = user_msgs.active_ebs_cluster % ctx
        else:
            self.msg = user_msgs.cluster_exists % ctx


class CancelledStartRequest(BaseException):
    def __init__(self, tag):
        self.msg = "Request to start cluster '%s' was cancelled!!!" % tag
        self.msg += "\n\nPlease be aware that instances may still be running."
        self.msg += "\nYou can check this from the output of:"
        self.msg += "\n\n   $ tethyscluster listclusters"
        self.msg += "\n\nIf you wish to destroy these instances please run:"
        self.msg += "\n\n   $ tethyscluster terminate %s" % tag
        self.msg += "\n\nYou can then use:\n\n   $ tethyscluster listclusters"
        self.msg += "\n\nto verify that the cluster has been terminated."
        self.msg += "\n\nIf you would like to re-use these instances, rerun"
        self.msg += "\nthe same start command with the -x (--no-create) option"


class CancelledCreateVolume(BaseException):
    def __init__(self):
        self.msg = "Request to create a new volume was cancelled!!!"
        self.msg += "\n\nPlease be aware that volume host instances"
        self.msg += " may still be running. "
        self.msg += "\n\nTo destroy these instances:"
        self.msg += "\n\n   $ tethyscluster terminate %s"
        self.msg += "\n\nYou can then use\n\n   $ tethyscluster listinstances"
        self.msg += "\n\nto verify that the volume hosts have been terminated."
        self.msg %= static.VOLUME_GROUP_NAME


class CancelledCreateImage(BaseException):
    def __init__(self, bucket, image_name):
        self.msg = "Request to create an S3 AMI was cancelled"
        self.msg += "\n\nDepending on how far along the process was before it "
        self.msg += "was cancelled, \nsome intermediate files might still be "
        self.msg += "around in /mnt on the instance."
        self.msg += "\n\nAlso, some of these intermediate files might "
        self.msg += "have been uploaded to \nS3 in the '%(bucket)s' bucket "
        self.msg += "you specified. You can check this using:"
        self.msg += "\n\n   $ tethyscluster showbucket %(bucket)s\n\n"
        self.msg += "Look for files like: "
        self.msg += "'%(iname)s.manifest.xml' or '%(iname)s.part.*'"
        self.msg += "\nRe-executing the same s3image command "
        self.msg += "should clean up these \nintermediate files and "
        self.msg += "also automatically override any\npartially uploaded "
        self.msg += "files in S3."
        self.msg = self.msg % {'bucket': bucket, 'iname': image_name}


CancelledS3ImageCreation = CancelledCreateImage


class CancelledEBSImageCreation(BaseException):
    def __init__(self, is_ebs_backed, image_name):
        self.msg = "Request to create EBS image %s was cancelled" % image_name
        if is_ebs_backed:
            self.msg += "\n\nDepending on how far along the process was "
            self.msg += "before it was cancelled, \na snapshot of the image "
            self.msg += "host's root volume may have been created.\nPlease "
            self.msg += "inspect the output of:\n\n"
            self.msg += "   $ tethyscluster listsnapshots\n\n"
            self.msg += "and clean up any unwanted snapshots"
        else:
            self.msg += "\n\nDepending on how far along the process was "
            self.msg += "before it was cancelled, \na new volume and a "
            self.msg += "snapshot of that new volume may have been created.\n"
            self.msg += "Please inspect the output of:\n\n"
            self.msg += "   $ tethyscluster listvolumes\n\n"
            self.msg += "   and\n\n"
            self.msg += "   $ tethyscluster listsnapshots\n\n"
            self.msg += "and clean up any unwanted volumes or snapshots"


class ExperimentalFeature(BaseException):
    def __init__(self, feature_name):
        self.msg = "%s is an experimental feature for this " % feature_name
        self.msg += "release. If you wish to test this feature, please set "
        self.msg += "ENABLE_EXPERIMENTAL=True in the [global] section of the"
        self.msg += " config. \n\nYou've officially been warned :D"


class ThreadPoolException(BaseException):
    def __init__(self, msg, exceptions):
        self.msg = msg
        self.exceptions = exceptions

    def print_excs(self):
        print self.format_excs()

    def format_excs(self):
        excs = []
        for exception in self.exceptions:
            e, tb_msg, jobid = exception
            excs.append('error occurred in job (id=%s): %s' % (jobid, str(e)))
            excs.append(tb_msg)
        return '\n'.join(excs)


class IncompatibleCluster(BaseException):
    default_msg = """\
INCOMPATIBLE CLUSTER: %(tag)s

The cluster '%(tag)s' is not compatible with TethysCluster %(version)s. \
Possible reasons are:

1. The '%(group)s' group was created using an incompatible version of \
TethysCluster (stable or development).

2. The '%(group)s' group was manually created outside of TethysCluster.

3. One of the nodes belonging to '%(group)s' was manually created outside of \
TethysCluster.

4. TethysCluster was interrupted very early on when first creating the \
cluster's security group.

In any case '%(tag)s' and its nodes cannot be used with this version of \
TethysCluster (%(version)s).

The cluster '%(tag)s' currently has %(num_nodes)d active nodes.

Please terminate the cluster using:

    $ tethyscluster terminate --force %(tag)s
"""

    def __init__(self, group):
        tag = group.name.replace(static.SECURITY_GROUP_PREFIX, '')
        states = ['pending', 'running', 'stopping', 'stopped']
        insts = group.connection.get_all_instances(
            filters={'instance-state-name': states,
                     'instance.group-name': group.name})
        ctx = dict(group=group.name, tag=tag, num_nodes=len(insts),
                   version=static.VERSION)
        self.msg = self.default_msg % ctx



# Copyright 2009-2014 Justin Riley
#
# This file is part of TethysCluster.
#
# TethysCluster is free software: you can redistribute it and/or modify it under
# the terms of the GNU Lesser General Public License as published by the Free
# Software Foundation, either version 3 of the License, or (at your option) any
# later version.
#
# TethysCluster is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
# details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with TethysCluster. If not, see <http://www.gnu.org/licenses/>.


class Validator(object):
    """
    Base class for all validating classes
    """
    def validate(self):
        """
        Raises an exception if any validation tests fail
        """
        pass

    def is_valid(self):
        """
        Returns False if any validation tests fail, otherwise returns True
        """
        pass
